/* Stats - proto.h - Function prototypes
**
** CVS $Id: proto.h,v 1.13 2001/02/15 01:16:39 wcampbel Exp $
**
*/

#ifndef PROTO_H
#define PROTO_H

#include "stats.h"

#ifdef SOLARIS
#define bzero(x, y)       memset((x), '\0', (y));
#define bcopy(x,y,z)      memcpy((y),(x),(z))
#endif /* SOLARIS */

/* Macros that were in m_stats.h */
#define DecreaseOpers(x)        x->opers--; me.opers--;
#define DecreaseUsers(x)        x->users--; me.users--;
#define DecreaseServers()       me.servers--;

/* External variables... */
extern int servsock;
extern char s_StatServ[MAXNICK], s_Spam[8];
extern const char version[];

#ifdef SUPPORT_MSG_UH
extern char s_UH[MAXUSER + MAXHOST + 2];
#endif

#ifdef SUPPORT_MSG_OPERS
extern char s_OPERS[MAXHOST + 7];
#endif

/* sock.c */
int ConnectTo(char *, int);
void read_loop();
void sts(char *, ...);

/* util.c */
void log(char *, ...);
void ResetLogs();
char *sctime(time_t);
char *sftime(time_t);
char *irc_time(time_t);
#if defined(CRYPT) || defined(MD5)
char *make_salt();
#endif /* CRYPT || MD5 */
int tokenize(char *message, char **parv);
int msgtoken(char *message, char **parv);
void *smalloc(size_t);
char *sstrdup(const char *);
unsigned long HASH(const unsigned char *, int);
char *strlower(char *);
char *VersionFlags();

/* conf.c */
void strip(char *);
void InitDefaults();
void ConfLoad();
int GetChanList();
void rehash();

/* main.c */
void login();
void init_statserv();
void init_spam();
void init_join();

/* ircd.c */
void parse();
void privmsg(char *, const char *, char *, ...);
void privmsg_list(char *, char *, const char **);
void globops(char *, char *, ...);
int flood(User *);
void SendQuit(User *, int, char *);
void Trace(User *);
void ParseStats(User *, char);

/* timer.c */
void chk();
void TimerReset();
void TimerSpam();
void TimerPings();
void TimerMidnight();
int is_midnight();

/* statserv.c */
void statserv(char *, char *);
void spam(char *, char *);

/* users.c */
Server *serverlist[S_TABLE_SIZE];
User *userlist[U_TABLE_SIZE];
MyUser *myuhead;
#ifdef IRCD_2_10
void AddUser(char *, char *, char *, Server *);
#else
void AddUser(char *, char *, char *, char *);
#endif
void DelUser(char *);
void Change_User(User *, char *);
User *finduser(char *);
void UserMode(char *, char *);
void init_user_hash();
#ifdef IRCD_2_10
void AddServer(char *, int, int, char *, char *);
Server *findservtoken(int);
#else
void AddServer(char *, int, char *, char *);
#endif
void FlushServer(char *);
void DelServer(char *);
Server *findserver(char *);
void init_server_hash();
void LoadMyUsers();
void SaveMyUsers();
void DeleteMyUser(char *);
MyUser *findmyuser(char *);

/* stats.c */
Stats *shead;
TLD *tldhead;
char *uptime(time_t);
TLD *findtld(char *);
TLD *AddTLD(User *);
void LoadTLD();
void init_tld();
void IncreaseOpers(Server *);
void IncreaseUsers(Server *);
void IncreaseServers();
void AddStats(Server *);
Stats *findstats(char *);
void SaveStats();
void LoadStats();

/* html.c */
void DumpHTML();

#endif
